Writing your first XML Résumé

# XMLRésuméLibrary: User Guide

Advanced Features of the XML Résumé Library | Exploring the Features of XML Résumé Library | Where to Go from Here

## Writing your first XML Résumé

This is the fun part. Take a look at both example résumés and choose one suits you best. Then replace the existing information with your own. You may also be able to find example résumés of real people by search for `XML resume` on the internet.

For complete information on the elements valid for the XML Résumé Library see Element Reference.

Advanced Features of the XML Résumé Library | Exploring the Features of XML Résumé Library | Where to Go from Here